%define Werror_cflags %nil

# (tv) fix "build-grub-module-verifier: error: increment: unsupported relocation 0x1d":
%undefine _hardened_build

%ifarch x86_64
%global my_efi_arch x86_64-efi
%endif

%ifarch %arm
%global my_efi_arch arm-efi
%endif

%ifarch %ix86
%global my_efi_arch i386-efi
%endif

%ifarch aarch64
%global my_efi_arch arm64-efi
%endif

%global tarversion 2.12
%undefine _missing_build_ids_terminate_build
%global _configure_gnuconfig_hack 0

%global pc_arch i386-pc

%global theme_version 1.3
%global theme_source grub2-theme-%{theme_version}

%global theme_fonts MageiaLogoBold-16 MageiaLogoRegular-20 MageiaLogoBold-20 MageiaLogoBold-28

# Use 'commits since release tag' from git describe as the version minor
# so we can sanely implement snapshots without reconfiguring the spec.
# Using './make_snapshot_patch' creates a patch with the %%{git} (minor) 
# number in the name.
# Add the patch name as Patch0000: in SOURCES/grub.patches
%define git	0


# It's a commit from their gnulib's development tree.  They don't do releases,
# and it is *awful* to update this.
%global gnulibversion 9f48fb992a3d7e96610c4ce8be969cff2d61a01b

Name:		grub2
Version:	2.12
Release:	%mkrel 6
Summary:	Bootloader with support for Linux, Multiboot and more
Group:		System/Boot and Init
License:	GPLv3+
URL:		https://www.gnu.org/software/grub/
Source0:	https://ftp.gnu.org/gnu/grub/grub-%{tarversion}.tar.xz
Source1:	grub.macros
Source2:	gnulib-%{gnulibversion}.tar.gz
Source4:	https://unifoundry.com/pub/unifont/unifont-13.0.06/font-builds/unifont-13.0.06.pcf.gz
Source6:	gitignore
Source7:	bootstrap
Source8:	bootstrap.conf
Source9:	strtoull_test.c
Source11:	grub.patches
Source12:	sbat.csv.in
# 
# Mageia sources:
#
# Explain diff with FC:
Source100:	00_SUMMARY
Source101:	README.Mageia
Source102:	README.efi
Source110:	https://gitweb.mageia.org/software/design/grub2-theme/snapshot/%{theme_source}.tar.xz
Source111:	mageia.macros
# TODO/FIXME: Should be split as a standalone theme pkg:
Source114:	grub2-mageia-default.png
Source20:	theme.txt
Source21:	make_snapshot_patch
Source52:	grub.default

%include %{SOURCE1}
%include %{SOURCE111}

BuildRequires:	gcc efi-srpm-macros
BuildRequires:	autoconf
BuildRequires:	autogen
BuildRequires:	automake
BuildRequires:	binutils
BuildRequires:	bison
BuildRequires:	bzip2-devel
BuildRequires:	pkgconfig(devmapper)
BuildRequires:	flex
BuildRequires:	freetype2-devel
BuildRequires:	freetype-devel
BuildRequires:	freetype-devel
BuildRequires:	pkgconfig(fuse3)
BuildRequires:	gettext-devel
BuildRequires:	git
BuildRequires:	glibc-devel
BuildRequires:	liblzo-devel
BuildRequires:	libusb-devel
BuildRequires:	pkgconfig(ncurses)
BuildRequires:	python3
BuildRequires:	rpm-devel
BuildRequires:	ruby
BuildRequires:	squashfs-tools
BuildRequires:	texinfo
BuildRequires:	help2man
BuildRequires:	pesign >= 0.99-8

Provides:	bootloader
Provides:	grub2bootloader = %{version}-%{release}
Requires:	grub2-common = %{version}-%{release}
Recommends:	grub2-mkfont

%global desc \
This is the second version of GRUB. \
The GRand Unified Bootloader (GRUB) is a highly configurable and \
customizable bootloader with modular architecture.  It supports a rich \
variety of kernel formats, file systems, computer architectures and \
hardware devices.\
Refer to the README.Mageia file that is part of this package's documentation \
for more information. \
%{nil}

# generate with do-rebase
%include %{SOURCE11}

#
# Mga patches:
#
Patch20001:	grub2-2.12-mga-add_failsafe-10_linux.in.patch
Patch20003:	grub2-2.00-mga-dont_write_diskfilter_error_to_screen.patch
Patch20004:	grub2-2.00-mga-dont_check_uuid_in_installer.patch
Patch20006:	grub2-2.02-mga-translate-theme-label.patch
Patch20007:	grub2-2.12-disable_fdt_on_arm-uboot.patch
Patch20008:	grub2-2.02-mga-translate-theme-title.patch
# Fix https://savannah.gnu.org/bugs/?57889
# fix finding Mageia efi
Source20010:	grub-2.04-find-boot-EFI.patch
# Restore the upstream x86 'linux' command, which is removed by the FC
# patches. Rename it to 'linux32' to avoid clashing with the FC aliases.
# This is currently needed to run pcmemtest when booted by a UEFI BIOS.
Source20011:	grub2-2.12-mga-restore-linux-32bit-loader.patch
# Don't create boot menu entries for the vmlinuz/initrd soft links in /boot (mga#31621).
Patch20013:	grub2-2.06-mga-10_linux.in-skip-initrd-links.patch

#
# SuSE Patch:
#
# Fixes Mga#15846 - Grub2 doesn't install the bootloader on btrfs if we
# have a dualboot with windows starting at sector 63
Patch30001:	grub2-setup-try-fs-embed-if-mbr-gap-too-small.patch

#
# Unity Patches
#

#
# Upstream Patches
#

%description
%{desc}

%package efi
Summary:	Boot-loader with support for EFI
Group:		System/Boot and Init

Requires(post):	efibootmgr
Provides:	bootloader
Provides:	grub2bootloader = %{version}-%{release}
Requires:	grub2-common = %{version}-%{release}

%description efi
%{desc}
This subpackage supports EFI platforms.

%ifarch %arm
%package uboot
Summary:	Boot-loader with support for  UBOOT
Group:		System/Boot and Init

Provides:	bootloader
Provides:	grub2bootloader = %{version}-%{release}
Requires:	grub2-common = %{version}-%{release}

%description uboot
configurable and customizable boot-loader with modular architecture.
It supports a wide range of kernel formats, file systems, computer
architectures and hardware devices.
%endif
%if 0%{with_xen_arch}
%{expand:%define_xen_variant %%{xen_package_arch} -o}
%endif
%if 0%{with_xen_pvh_arch}
%{expand:%define_xen_pvh_variant %%{xen_pvh_package_arch} -o}
%endif

%package common
Summary:	Provides files common to both grub2 and grub2-efi
Group:		System/Boot and Init
Conflicts:	memtest86+ < 5.01-7
Conflicts:	grub2 < 2.02-0.git9752.19.mga5
Conflicts:	grub2-efi < 2.02-0.git9752.19.mga5
Recommends:	os-prober >= 1.53
Recommends:	xorriso
Requires:	grub2bootloader = %{version}-%{release}
Requires:	console-setup
Requires:	mtools

%description common
Common files used by both grub2 and grub2-efi.

%package mageia-theme
Summary:	Provides a graphical theme with a custom Mageia background for grub2
Group:		System/Boot and Init

Requires:	grub2bootloader = %{version}
Requires(post):	sed
Requires(post):	coreutils
Conflicts:	grub2-mageia-theme-dejavu

BuildArch:	noarch

%description mageia-theme
This package provides a custom Mageia graphical theme.
It is provided as a separate package so it may be easily excluded from
minimal installations where a graphical theme is not required.

%package mkfont
Summary:	Provides mkfont tool for grub2
Group:		System/Boot and Init
Requires:	grub2bootloader = %{version}
Conflicts:	grub2 < 2.12-3
Conflicts:	grub2-common < 2.12-4

%description mkfont
This package provides mkfont for grub2
It is provided as a separate package so it may be easily excluded from
minimal installations dependencies where libfreetype and its deps 
such as libx11 is not needed

%if 0%{with_emu_arch}
%package emu
Summary:	GRUB user-space emulation
Requires:	grub2-common = %{version}-%{release}

%description emu
%{desc}
This subpackage provides the GRUB user-space emulation support of all platforms.

%package emu-modules
Summary:	GRUB user-space emulation modules
Requires:	grub2-common = %{version}-%{release}

%description emu-modules
%{desc}
This subpackage provides the GRUB user-space emulation modules.
%endif

%prep
# Theme translations and fonts
tar xf %{SOURCE110}

%do_common_setup
%merge_theme_translations


%if 0%{with_efi_arch}
mkdir grub-%{grubefiarch}-%{tarversion}
grep -A100000 '# stuff "make" creates' .gitignore > grub-%{grubefiarch}-%{tarversion}/.gitignore
cp %{SOURCE4} grub-%{grubefiarch}-%{tarversion}/unifont.pcf.gz
sed -e "s,@@VERSION@@,%{version},g" -e "s,@@VERSION_RELEASE@@,%{version}-%{release},g" \
    %{SOURCE12} > grub-%{grubefiarch}-%{tarversion}/sbat.csv
git add grub-%{grubefiarch}-%{tarversion}
%endif
%if 0%{with_alt_efi_arch}
mkdir grub-%{grubaltefiarch}-%{tarversion}
grep -A100000 '# stuff "make" creates' .gitignore > grub-%{grubaltefiarch}-%{tarversion}/.gitignore
cp %{SOURCE4} grub-%{grubaltefiarch}-%{tarversion}/unifont.pcf.gz
git add grub-%{grubaltefiarch}-%{tarversion}
%endif
%if 0%{with_legacy_arch}
mkdir grub-%{grublegacyarch}-%{tarversion}
grep -A100000 '# stuff "make" creates' .gitignore > grub-%{grublegacyarch}-%{tarversion}/.gitignore
cp %{SOURCE4} grub-%{grublegacyarch}-%{tarversion}/unifont.pcf.gz
git add grub-%{grublegacyarch}-%{tarversion}
%endif
%if 0%{with_emu_arch}
mkdir grub-emu-%{tarversion}
grep -A100000 '# stuff "make" creates' .gitignore > grub-emu-%{tarversion}/.gitignore
cp %{SOURCE4} grub-emu-%{tarversion}/unifont.pcf.gz
git add grub-emu-%{tarversion}
%endif
%if 0%{with_xen_arch}
mkdir grub-%{grubxenarch}-%{tarversion}
grep -A100000 '# stuff "make" creates' .gitignore > grub-%{grubxenarch}-%{tarversion}/.gitignore
cp %{SOURCE4} grub-%{grubxenarch}-%{tarversion}/unifont.pcf.gz
sed -e "s,@@VERSION@@,%{version},g" -e "s,@@VERSION_RELEASE@@,%{version}-%{release},g" \
    %{SOURCE12} > grub-%{grubxenarch}-%{tarversion}/sbat.csv
git add grub-%{grubxenarch}-%{tarversion}
%endif
%if 0%{with_xen_pvh_arch}
mkdir grub-%{grubxenpvharch}-%{tarversion}
grep -A100000 '# stuff "make" creates' .gitignore > grub-%{grubxenpvharch}-%{tarversion}/.gitignore
cp %{SOURCE4} grub-%{grubxenpvharch}-%{tarversion}/unifont.pcf.gz
sed -e "s,@@VERSION@@,%{version},g" -e "s,@@VERSION_RELEASE@@,%{version}-%{release},g" \
    %{SOURCE12} > grub-%{grubxenpvharch}-%{tarversion}/sbat.csv
git add grub-%{grubxenpvharch}-%{tarversion}
%endif
git commit -m "After making subdirs"

# README.Mageia
cp %{SOURCE101} .
 
# README.efi
cp %{SOURCE102} .

%build
%if 0%{with_efi_arch}
%{expand:%do_primary_efi_build %%{grubefiarch} %%{grubefiname} %%{grubeficdname} %%{_target_platform} %%{efi_target_cflags} %%{efi_host_cflags}}
%endif
%if 0%{with_alt_efi_arch}
%{expand:%do_alt_efi_build %%{grubaltefiarch} %%{grubaltefiname} %%{grubalteficdname} %%{_alt_target_platform} %%{alt_efi_target_cflags} %%{alt_efi_host_cflags}}
%endif
%if 0%{with_legacy_arch}
%{expand:%do_legacy_build %%{grublegacyarch}}
%endif
%if 0%{with_emu_arch}
%{expand:%do_emu_build}
%endif
%if 0%{with_xen_arch}
%{expand:%do_xen_build %%{grubxenarch} %%{_target_platform} %%{xen_target_cflags} %%{xen_host_cflags}}
%endif
%if 0%{with_xen_pvh_arch}
%{expand:%do_xen_pvh_build %%{grubxenpvharch} %%{_target_platform} %%{xen_pvh_target_cflags} %%{xen_pvh_host_cflags}}
%endif
makeinfo --info --no-split -I docs -o docs/grub-dev.info \
docs/grub-dev.texi
makeinfo --info --no-split -I docs -o docs/grub.info \
docs/grub.texi
makeinfo --html --no-split -I docs -o docs/grub-dev.html \
docs/grub-dev.texi
makeinfo --html --no-split -I docs -o docs/grub.html \
docs/grub.texi

%install
set -e

%do_common_install
%if 0%{with_efi_arch}
%{expand:%do_efi_install %%{grubefiarch} %%{grubefiname} %%{grubeficdname}}
%endif
%if 0%{with_alt_efi_arch}
%{expand:%do_alt_efi_install %%{grubaltefiarch} %%{grubaltefiname} %%{grubalteficdname}}
%endif
%if 0%{with_legacy_arch}
%{expand:%do_legacy_install %%{grublegacyarch} %%{alt_grub_target_name} 0%%{with_efi_arch}}
%endif
%if 0%{with_emu_arch}
%{expand:%do_emu_install %%{package_arch}}
%endif
%if 0%{with_xen_arch}
%{expand:%do_xen_install %%{grubxenarch}}
%endif
%if 0%{with_xen_pvh_arch}
%{expand:%do_xen_pvh_install %%{grubxenpvharch}}
%endif

%find_lang grub

# Theme
install -d %{buildroot}/boot/grub2/themes/maggy
install -D -m 644 %{SOURCE20} %{buildroot}/boot/grub2/themes/maggy
for font in %{theme_fonts}; do
  %{buildroot}/usr/bin/grub2-mkfont -o %{buildroot}/boot/grub2/themes/maggy/$font.pf2 ../%{theme_source}/fonts/$font.bdf
done
# Install 4:3 default in case default.jpg is missing
install -D -m 644 %{SOURCE114} %{buildroot}/boot/grub2/themes
ln -sf ../grub2-mageia-default.png %{buildroot}/boot/grub2/themes/maggy/grub2-mageia-default.png

# Ghost config files
install -d %{buildroot}/boot/grub2
install -d %{buildroot}/boot/grub2/fonts

cat > %{buildroot}/boot/grub2/custom.cfg <<EOF
# Set non-graphical text/background colours
set menu_color_normal=cyan/blue
set menu_color_highlight=white/blue
# Add any extra custom menu entries in here:

EOF

# Provide 'update-grub' and update-grub2 symlink for *buntu exiles ;) 
cat > %{buildroot}%{_bindir}/update-grub <<EOF
#!/bin/sh
su --login root -c "/usr/sbin/grub2-mkconfig -o /boot/grub2/grub.cfg"

EOF
chmod +x %{buildroot}%{_bindir}/update-grub
ln -s %{_bindir}/update-grub %{buildroot}%{_bindir}/update-grub2

# Defaults
install -m 644 -D %{SOURCE52} %{buildroot}%{_sysconfdir}/default/grub

# Remove "GNU/Linux" in menu selections
sed -i 's/ GNU\/Linux//' %{buildroot}%{_sysconfdir}/grub.d/10_linux

install -d -m 0755 %{buildroot}%{_unitdir}/reboot.target.wants
ln -s ../grub2-systemd-integration.service \
	%{buildroot}%{_unitdir}/reboot.target.wants

# Don't run debuginfo on all the grub modules and whatnot; it just
# rejects them, complains, and slows down extraction.
%global finddebugroot "%{_builddir}/%{?buildsubdir}/debug"

%global dip RPM_BUILD_ROOT=%{finddebugroot} %{__debug_install_post}
%define __debug_install_post (						\
	mkdir -p %{finddebugroot}/usr					\
	mv ${RPM_BUILD_ROOT}/usr/bin %{finddebugroot}/usr/bin		\
	mv ${RPM_BUILD_ROOT}/usr/sbin %{finddebugroot}/usr/sbin		\
	%{dip}								\
	install -m 0755 -d %{buildroot}/usr/lib/ %{buildroot}/usr/src/	\
	cp -al %{finddebugroot}/usr/lib/debug/				\\\
		%{buildroot}/usr/lib/debug/				\
	cp -al %{finddebugroot}/usr/src/debug/				\\\
		%{buildroot}/usr/src/debug/ )				\
	mv %{finddebugroot}/usr/bin %{buildroot}/usr/bin		\
	mv %{finddebugroot}/usr/sbin %{buildroot}/usr/sbin		\
	%{nil}
 
%undefine buildsubdir

%post
if [ $1 -eq 2 ]; then
      touch /boot/grub2/updtrans
fi

%post efi
if [[ ! -e /boot/efi && -e /boot/EFI ]]; then
	ln -fs EFI /boot/efi
fi
if [ $1 -eq 2 ]; then
      touch /boot/grub2/updtrans
fi
# ensure we exit 0
:

%posttrans common
# On update re-install grub2 to where it was installed by drakboot if possible,
# otherwise next boot may fail due to mismatched boot code.
   if [ -f /boot/grub2/updtrans ] && [ -f /boot/grub2/install.sh -a -x /usr/sbin/detectloader ] && [ "$DURING_INSTALL" != "1" ] ; then
		LOADER=$(/usr/sbin/detectloader)
		[ "$LOADER" = "GRUB2" ] && /boot/grub2/install.sh ||:
		rm -f /boot/grub2/updtrans
   fi
   
# Don't let rpmdrake ask users to shoot themselves in feet! Mga#17263
		rm -f /etc/default/grub.rpm*

%post mageia-theme
# Don't install if updating
if [ $1 -eq 1 ] ; then
# Remove trailing blank lines from /etc/default/grub
sed -i -e :a -e '/^\n*$/{$d;N;};/\n$/ba' %{_sysconfdir}/default/grub
# Check that /etc/default/grub ends in a linefeed
[ "$(tail -n 1 %{_sysconfdir}/default/grub | wc --lines)" = "1" ] || echo >> %{_sysconfdir}/default/grub
# Add theme
echo "GRUB_THEME=/boot/grub2/themes/maggy/theme.txt" >> %{_sysconfdir}/default/grub

# If installing theme outside installer then update menu 
if [ "x${DURING_INSTALL}" != "x1" ]; then
grub2-mkconfig -o /boot/grub2/grub.cfg && rm -f /boot/grub2/grub.cfg.rpmsave
fi
fi

# Copy system default background at correct aspect ratio to grub2 default theme
if [ -h %{_datadir}/mga/backgrounds/default.png ] && [ "$DURING_INSTALL" != "1" ]; then
cp -f %{_datadir}/mga/backgrounds/default.png /boot/grub2/themes/grub2-mageia-default.png
fi

%triggerpostun mageia-theme -- grub2-mageia-theme <  2.02-0.git10463.5.mga6
# Run install.sh to replace /boot/grub2/fonts/unicode.pf2
   if [ -f /boot/grub2/install.sh -a -x /usr/sbin/detectloader ] && [ "$DURING_INSTALL" != "1" ]; then
		LOADER=$(/usr/sbin/detectloader)
		[ "$LOADER" = "GRUB2" ] && /boot/grub2/install.sh ||:
   fi

# If updating from below 2.02-0.git10101.4 then re-make grub.cfg once.
# grub2 dropped ownership of grub.cfg to avoid rpmnew being created.
# Remove rpmnew and after new grub.cfg is created remove rpmsave. Mga#17263
%triggerpostun common -- grub2 < 2.02-0.git10101.4, grub2-efi < 2.02-0.git10101.4
rm -f /boot/grub2/grub.cfg.rpmnew
grub2-mkconfig -o /boot/grub2/grub.cfg && rm -f /boot/grub2/grub.cfg.rpmsave
# Take this opportunity to remove some unwanted logs
rm -f /var/log/grub2_preun.log
rm -f /var/log/grub2_post.log
rm -f /var/log/grub2_theme_postun.log

%preun
# Only if uninstalling
if [ $1 -eq 0 ]; then
rm -rf /boot/grub2/%{pc_arch}
rm -rf /boot/grub2/locale
fi

%preun efi
# Only if uninstalling
if [ $1 -eq 0 ]; then
rm -rf /boot/grub2/%{my_efi_arch}
rm -rf /boot/grub2/locale
fi

%postun mageia-theme
# Only if uninstalling theme
if [ $1 -eq 0 ]; then
# Remove theme from config
sed -i '/GRUB_THEME=\/boot\/grub2\/themes\/maggy\/theme.txt/d' %{_sysconfdir}/default/grub
fi

%ifarch %ix86 x86_64
%files
%dir %{_libdir}/grub/i386-pc
%{_libdir}/grub/i386-pc/*
%attr(0644,root,root) %config(noreplace) /etc/dnf/protected.d/grub2-pc.conf
%endif

%files efi 
%doc README.efi
%dir %{_libdir}/grub/%{my_efi_arch}
%{_libdir}/grub/%{my_efi_arch}/*
%{_sysconfdir}/grub2-efi.cfg
%ifarch %{arm}
%attr(0700,root,root)%{efi_esp_boot}/BOOTARM.EFI
%endif
%attr(0644,root,root) %config(noreplace) /etc/dnf/protected.d/grub2-efi*.conf

%ifarch %arm
%files uboot
%dir %{_libdir}/grub/%{grublegacyarch}
%{_libdir}/grub/%{grublegacyarch}/*
%attr(0644,root,root) %config(noreplace) /etc/dnf/protected.d/grub2-arm.conf
%endif
%if 0%{with_xen_arch}
%{expand:%define_xen_variant_files %%{xen_package_arch} %%{xen_grub_target_name}}
%endif
%if 0%{with_xen_pvh_arch}
%{expand:%define_xen_pvh_variant_files %%{xen_pvh_package_arch} %%{xen_pvh_grub_target_name}}
%endif

%files common -f grub.lang
%license COPYING
%doc NEWS README THANKS TODO README.Mageia
%dir /boot/grub2
/boot/grub2/fonts
%dir /boot/grub2/themes
%dir %attr(0700,root,root) %{efi_esp_dir}
%exclude %{efi_esp_dir}/*
%{_unitdir}/grub2-systemd-integration.service
%{_unitdir}/reboot.target.wants
%{_unitdir}/systemd-logind.service.d
%{_infodir}/*
%{_bindir}/grub2-*
%exclude %{_bindir}/grub2-mkfont
%if 0%{with_emu_arch}
%exclude %{_bindir}/grub2-emu*
%endif
%{_bindir}/update-grub
%{_bindir}/update-grub2
%{_sbindir}/grub2-*
%{_libexecdir}/grub2
%dir %{_libdir}/grub
%{_datarootdir}/bash-completion/completions/grub
%{_sysconfdir}/grub.d/README
%config %{_sysconfdir}/grub.d/[^4]?_*
%config(noreplace) %{_sysconfdir}/grub.d/40_custom
%config(noreplace) %{_sysconfdir}/grub.d/41_custom
%config(noreplace) %{_sysconfdir}/default/grub
%{_datadir}/grub/*
%{_sysconfdir}/sysconfig/grub
%config(noreplace) /boot/grub2/custom.cfg
%ghost %config(noreplace) %verify(not size mode md5 mtime) /boot/grub2/grubenv
%exclude /boot/grub2/grub.cfg
%{_mandir}/man1/grub2-*.1*
%exclude %{_mandir}/man1/grub2-mkfont.1*
%if 0%{with_emu_arch}
%exclude %{_mandir}/man1/grub2-emu*
%endif
%{_mandir}/man3/grub2-*.3*
%{_mandir}/man8/grub2-*.8*
%{_sysconfdir}/grub2.cfg

%files mageia-theme
/boot/grub2/themes/*

%files mkfont
%{_bindir}/grub2-mkfont
%{_mandir}/man1/grub2-mkfont.1*

%if 0%{with_emu_arch}
%files emu
%{_bindir}/grub2-emu*
%{_datadir}/man/man1/grub2-emu*

%files emu-modules
%{_libdir}/grub/%{emuarch}-emu/*
%exclude %{_libdir}/grub/%{emuarch}-emu/*.module
%endif


%changelog
* Fri Mar 07 2025 tv <tv> 2.12-6.mga10
+ Revision: 2161768
- fs/ext2: Rework out-of-bounds read for inline and external extents (rhbz#2346804)
- Add Several CVE fixes (rhbzCVE-2024-45781 CVE-2024-45783 CVE-2024-45778) (rhbzCVE-2024-45775 CVE-2024-45780 CVE-2024-45774) (rhbzCVE-2025-0690 CVE-2025-1118 CVE-2024-45782) (rhbzCVE-2025-0624 CVE-2024-45779 CVE-2024-45776) (rhbzCVE-2025-0622 CVE-2025-0677)
- commands/bli: Fix crash in get_part_uuid() (rhbz#2339164)
- fix pending SAST issues (#RHEL-50504)
- term/nns8250-spcr: return if redirection is disabled
- fs/xfs: fix large extent counters incompat feature support
- Add riscv64 support (thanks Jason Montleon)
- Build modules for Xen PV and PVH
- cmd/search: Fix a possible NULL ptr dereference
- acpi: Fix out of bounds access in grub_acpi_xsdt_find_table() (rhbz#2317048)
- Stop grub.efi from always printing "dynamic_load_symbols %%p\n" during boot (rhbz#2316279)
- NX: efi/loader, add a call to grub_efi_check_nx_required()
- aarch64/macros: Build gnulib with -mbranch-protection=standard
- load EFI commands inside test expressions (rhbz#2305291)
- Fix netbooting regressions introduced at 2.12-1 (rhbz#2303727)
  NOPE:
- posttrans: added check for efi_home/grub.cfg (rhbz#2326502)
- do-rebase: refactor command line parameters
  NO:
- 99-grub-mkconfig.install: on PPC systems, remove petiboot's version checks
- 99-grub-mkconfig.install: Disable BLS and run grub2-mkconfig when GRUB_ENABLE_BLSCFG is disable (rhbz#2325960)

* Tue Oct 29 2024 wally <wally> 2.12-5.mga10
+ Revision: 2111731
- skip pxe build on armv7hl as arm-uboot seems to be unsupported

* Tue Oct 29 2024 wally <wally> 2.12-4.mga10
+ Revision: 2111712
- make mkfont sub pkg arch-dependant
- move mkfont man page into correct pkg
- add proper conflicts after file moves between pkgs

* Tue Oct 29 2024 bcornec <bcornec> 2.12-3.mga10
+ Revision: 2111650
- Create a separate grub2-mkfont package to allow a really minimal install without libfreetype dep

* Fri Aug 30 2024 tv <tv> 2.12-2.mga10
+ Revision: 2092228
- Use %%{ix86} instead of i586, which explained the local success with
  "linux32 iurt --repository /mageia/ -r unstable i586" vs BS using "i686"
- Fix "build-grub-module-verifier: error: increment: unsupported relocation 0x1d" by disabling hardnening
- Disable linux32 patch (for pcmemtest as it breaks build due to duplicated symbols)
- Drop old workaround for missing translations: no more needed
- Rebased to release grub2-2.12
- Build using fuse3

* Tue Mar 26 2024 ns80 <ns80> 2.06-30.mga10
+ Revision: 2052230
- add patches from Fedora for CVE-2023-469[23], CVE-2023-4001 and CVE-2024-1048 (mga#32997)

* Fri Sep 01 2023 papoteur <papoteur> 2.06-29.mga10
+ Revision: 1983347
- Fix the position of the progress bar, to avoid it overlapping logo

* Tue Aug 08 2023 tmb <tmb> 2.06-28.mga9
+ Revision: 1964511
- merge patches 320-323, 325-332 from  fedora for grub out-of-memory
  issues, arm64 uefi crash fixes and some minor bugfixes

* Wed May 17 2023 martinw <martinw> 2.06-27.mga9
+ Revision: 1957100
- Fix failure to recognise/read f2fs filesystem (mga#31923)

* Mon Apr 17 2023 martinw <martinw> 2.06-26.mga9
+ Revision: 1953481
- New artwork for Mageia 9
- Change text colour for better contrast with new artwork

* Fri Apr 07 2023 martinw <martinw> 2.06-25.mga9
+ Revision: 1951663
- Don't create boot menu entries for the vmlinuz/initrd soft links in /boot (mga#31621)

* Mon Feb 20 2023 tv <tv> 2.06-24.mga9
+ Revision: 1944393
- Fix disk sector size computation
- Override the linker and force nonexecutable stacks
- emu: support newer kexec syscall
- Fix implicit function declaration warnings
- 20-grub-install: Explicitly check '+debug' suffix for debug kernels
- Fix grub2-probe

* Mon Jan 02 2023 tv <tv> 2.06-23.mga9
+ Revision: 1929396
- Fix prefix setting with memdisk creation for network boot
- Fix error handling in grub_file_open()
- Allow for xz'd symvers file
- install unicode.pf2 into place so lorax works
- Bundle unicode.pf2 with images (rhbz#2143725, rhbz#2144113)
+ pterjan <pterjan>
- Replace non existing UNUSED macro with __attribute__ ((unused)) in some patches

* Thu Nov 17 2022 tv <tv> 2.06-22.mga9
+ Revision: 1908531
- Font fixes (CVE-2022-2601 batch)
- TDX measurements to RTMR
- Try dropping custom sort again

* Wed Oct 19 2022 ghibo <ghibo> 2.06-21.mga9
+ Revision: 1897530
- Add Patch 20012 to fix fgrep/grep -F warnings

* Sun Oct 16 2022 tv <tv> 2.06-20.mga9
+ Revision: 1897114
- x86-efi: Fix an incorrect array size in kernel allocation
- Flush instruction cache before starting aa64 kernel
- aa64: support pe/coff decompressor
- ieee1275: implement vec5 for cas negotiation
- Handle ostree's non-writable /etc/kernel
- Skip rpm mtime verification on likely-vfat filesystems
- Use --with-rpm-version

* Mon Aug 15 2022 tv <tv> 2.06-19.mga9
+ Revision: 1878040
- Revert EFI memory fixes

* Sun Aug 14 2022 tv <tv> 2.06-18.mga9
+ Revision: 1877595
- Try reserving less RAM to fix windows booting (rhbz#2115202)
- Allocator fixes for kernel
- Handle FAT mtime of 0 (rhbz#2096192)

* Thu Jun 16 2022 tv <tv> 2.06-17.mga9
+ Revision: 1864560
- CVE fixes for 2022-05-24
- Resolves: CVE-2022-28736 CVE-2022-28735 CVE-2022-28734 CVE-2022-28733
- Resolves: CVE-2021-3697 CVE-2021-3696 CVE-2021-3695
- Fix missing declaration of strchrnul in rpm-sort

* Mon Apr 25 2022 tv <tv> 2.06-16.mga9
+ Revision: 1853150
- Stop using %%{name} for things in the spec file (easier comp with FC)
- fix "grub2-mkrescue: error: `mformat` invocation failed"
- Attempt to fix version display
- Fix permission change report from rpm verification on grub.cfg

* Tue Apr 05 2022 tv <tv> 2.06-15.mga9
+ Revision: 1844905
- Switch to upstream man pages
- Fix missing format specifier in appended signature commit
- Don't verify kernels twice
- Fix missing format specifier in appended signature commit
- Don't verify kernels twice

* Sun Mar 13 2022 tv <tv> 2.06-13.mga9
+ Revision: 1790731
- Drop libusb dependency
- Fix initialization in efidisk patch

* Sun Feb 27 2022 tv <tv> 2.06-12.mga9
+ Revision: 1786262
- Add efidisk/connectefi patches
- Fix appended signature support commit
- Suffer through updating gnulib

* Wed Jan 19 2022 tv <tv> 2.06-11.mga9
+ Revision: 1769019
- Add location of DejaVu Sans font

* Sat Jan 08 2022 martinw <martinw> 2.06-10.mga9
+ Revision: 1767276
- update terminal-font setting in theme.txt to match updated unifont (mga#29838)

* Fri Jan 07 2022 tv <tv> 2.06-9.mga9
+ Revision: 1767220
- btrfs: use full bootloader area

* Mon Dec 13 2021 tv <tv> 2.06-8.mga9
+ Revision: 1761880
- restore umask for grub.cfg (CVE-2021-3981)

* Thu Nov 04 2021 tv <tv> 2.06-7.mga9
+ Revision: 1753934
- Drop UI patches and update provenance information

* Tue Oct 19 2021 tv <tv> 2.06-6.mga9
+ Revision: 1752205
- fs/xfs: Fix unreadable filesystem with v4 superblock
- Arm: check for the PE magic for the compiled arch
  (rhbz#2008819)
- Fix grub-mkimage --append-signature-size

* Sat Aug 28 2021 tv <tv> 2.06-5.mga9
+ Revision: 1743295
- Fix aarch64 kernel alignment (Fix EFI loader kernel image allocation)

* Wed Aug 18 2021 tv <tv> 2.06-4.mga9
+ Revision: 1741872
- Suppress gettext error message (rhbz#1592124
- grub-boot-success.timer: Only run if not in a container (rhbz#1914571)
- templates: Check for EFI at runtime instead of config generation time
  (rhbz#1823864)
- efi: Print an error if boot to firmware setup is not supported (rhbz#1823864)
- grub.macros: Install font in /boot/grub2 instead of the ESP
- grub.macros: Use consistent file mode for legacy and EFI
- Update to unifont-13.0.06
- Add luks2 to GRUB_MODULES
  Enable limited luks2 support for the built images.
  Argon2 keys. the default used in cryptsetup for luks2, are not yet supported.

* Mon Jun 14 2021 tv <tv> 2.06-2.mga9
+ Revision: 1730724
- Backport a cople fixes
- grub.macros: Include f2fs in GRUB_MODULES
  Enable GRUB to read F2FS filesystems.

* Wed Jun 09 2021 tv <tv> 2.06-1.mga9
+ Revision: 1730234
- 2.06 final

* Thu May 06 2021 tv <tv> 2.06~rc1-9.mga9
+ Revision: 1721719
- Add XFS needsrepair support

* Fri Apr 16 2021 tv <tv> 2.06~rc1-8.mga9
+ Revision: 1715965
- Add XFS bigtime support
- Fix a couple of merge mistakes made when rebasing to 2.06~rc1 (rhbz#1940524)
- fix grub2-mageia-theme's %%postun

* Sat Apr 10 2021 wally <wally> 2.06~rc1-7.mga9
+ Revision: 1714532
- don't pkg grub2-emu stuff into grub2-common (mga#28756)

* Thu Apr 01 2021 tv <tv> 2.06~rc1-6.mga9
+ Revision: 1712481
- Fix filelist on armv7

* Thu Apr 01 2021 tv <tv> 2.06~rc1-5.mga9
+ Revision: 1712469
- Rebuild for armv7

* Fri Mar 26 2021 pterjan <pterjan> 2.06~rc1-4.mga9
+ Revision: 1710737
- Try to fix arm build...

* Wed Mar 24 2021 tv <tv> 2.06~rc1-3.mga9
+ Revision: 1708902
- Fix menu (rhbz#1940524)

* Wed Mar 17 2021 tv <tv> 2.06~rc1-2.mga9
+ Revision: 1704157
- Restore support for UEFI w/o Secure Boot
  Though we should find a way to sign our grub2
- Update to 2.06~rc1 to fix a bunch of CVEs
  Resolves: CVE-2020-14372
  Resolves: CVE-2020-25632
  Resolves: CVE-2020-25647
  Resolves: CVE-2020-27749
  Resolves: CVE-2020-27779
  Resolves: CVE-2021-20225
  Resolves: CVE-2021-20233

* Wed Feb 17 2021 tmb <tmb> 2.04.0-29.mga8
+ Revision: 1675546
- translation updates

* Tue Feb 02 2021 martinw <martinw> 2.04.0-28.mga8
+ Revision: 1674535
- use dark blue for unselected items in Mageia theme for better contrast

* Wed Jan 13 2021 martinw <martinw> 2.04.0-27.mga8
+ Revision: 1671621
- update theme with new artwork

* Mon Jan 04 2021 martinw <martinw> 2.04.0-26.mga8
+ Revision: 1668661
- Revert broken support for setting grubenv boot status flags (mga#27269)
+ tv <tv>
- Fixed some typos in grub-install.8 man page

* Fri Nov 27 2020 tmb <tmb> 2.04.0-25.mga8
+ Revision: 1649786
- rebuild for missing signatures

* Tue Sep 01 2020 tv <tv> 2.04.0-24.mga8
+ Revision: 1620640
- Roll over TFTP block counter to prevent timeouts with data packets (rhbz#1869335)
- Add support for "systemctl reboot --boot-loader-menu=xx" (rhbz#1857389)
- Add support for setting boot_success / boot_indeterminate grubenv flags
  Add support for making the user session automatically set the boot_success
  flag and make offline-updates increment the boot_indeterminate grubenv var.

* Sat Aug 22 2020 tv <tv> 2.04.0-23.mga8
+ Revision: 1617814
- add missing patch

* Sat Aug 22 2020 tv <tv> 2.04.0-22.mga8
+ Revision: 1617807
- Set TFTP blocksize to 1428 instead of 2048 to avoid IP fragmentation
  (rhbz#1869335)
- Fix TFTP timeouts when trying to fetch files larger than 65535 KiB

* Fri Aug 21 2020 tv <tv> 2.04.0-21.mga8
+ Revision: 1617417
- fix license tag
- fix license tag

* Thu Aug 20 2020 tv <tv> 2.04.0-20.mga8
+ Revision: 1616717
- try to fix arm build

* Wed Aug 19 2020 tv <tv> 2.04.0-19.mga8
+ Revision: 1616131
- Attempt to enable dual-signing
- "Minor" bug fixes.
  Resolves: CVE-2020-10713
  Resolves: CVE-2020-14308
  Resolves: CVE-2020-14309
  Resolves: CVE-2020-14310
  Resolves: CVE-2020-14311
  Resolves: CVE-2020-15705
  Resolves: CVE-2020-15706
  Resolves: CVE-2020-15707

* Fri Jun 12 2020 martinw <martinw> 2.04.0-18.mga8
+ Revision: 1592943
- build with -Os so core.img fits in MBR 63 sector gap (mga#26778)
+ tv <tv>
- http: Prepend prefix when the HTTP path is relative as done in efi/http

* Mon Jun 08 2020 tv <tv> 2.04.0-17.mga8
+ Revision: 1590926
- fix build with rpm-4.16
- Install GRUB as \EFI\BOOT\BOOTARM.EFI in armv7hl

* Fri May 29 2020 martinw <martinw> 2.04.0-16.mga8
+ Revision: 1588860
- restore the upstream 'linux' command, renamed to 'linux32'
  o allows booting using the 32-bit Linux boot protocol
- translation updates for Mageia theme
+ tv <tv>
- Fix an out of memory error when loading large initrd images (rhbz#1838633)
- Enable tpm module and make system to boot even if TPM measurements fail
  (rhbz#1836433)

* Wed May 13 2020 tv <tv> 2.04.0-15.mga8
+ Revision: 1583552
- Fix a segfault in grub2-editenv when attempting to shrink a variable

* Sun Apr 26 2020 tv <tv> 2.04.0-14.mga8
+ Revision: 1572212
- disable another BLS patch

* Sat Apr 25 2020 tv <tv> 2.04.0-13.mga8
+ Revision: 1571997
- disable BLS
- symlink /boot/efi -> /boot/EFI
- BR python3 rather than py2

* Sat Apr 25 2020 tmb <tmb> 2.04.0-12.mga8
+ Revision: 1571916
- fix detecting Mageia /boot/EFI

* Fri Apr 24 2020 tv <tv> 2.04.0-11.mga8
+ Revision: 1571666
- efi: Set image base address before jumping to the PE/COFF entry point, needed
  for kernel 5.7 (rhbz#1825411)
- Make the grub-switch-to-blscfg and 10_linux scripts more robust

* Thu Apr 02 2020 tv <tv> 2.04.0-10.mga8
+ Revision: 1564013
- resync patches with FC
  o grub-set-bootflag: Write new env to tmpfile and then rename
    (CVE-2019-14865, rhbz#1776580)
  o re-enable BLS as it doesn't generate doble entries anymore
  o Fix for entries having an empty initrd command and HTTP boot issues
    (rhbz#1806022)
- enable SDL support in grub2-emu

* Sat Feb 29 2020 martinw <martinw> 2.04.0-9.mga8
+ Revision: 1552458
- fix directory/file ownership (breakage from FC sync)

* Sat Feb 29 2020 tv <tv> 2.04.0-8.mga8
+ Revision: 1552365
- relax /boot/grub2 permissions so that we can build d-i-images

* Sat Feb 29 2020 martinw <martinw> 2.04.0-7.mga8
+ Revision: 1552247
- fix grub-install to copy locale files (upstream bug #57889)
- restore missing translations (workaround upstream bug #57298)
- add ability to translate theme menu title
- add theme menu title and footer text translations
  (taken from software/design/grub2-theme snapshot
   and merged into upstream .po/.mo files)
- get MageiaLogo fonts from software/design/grub2-theme snapshot

* Tue Feb 18 2020 pterjan <pterjan> 2.04.0-6.mga8
+ Revision: 1537987
- Fix file list in arm-uboot
- Disable fdt on arm_uboot
- Also build efi package on arm

* Mon Feb 17 2020 tv <tv> 2.04.0-4.mga8
+ Revision: 1536944
- disable BLS support for now b/c of doubled entries
- drop mga5 era conflicts
- update SuSE patch & drop my fixup
- do not hardcode mga6
+ pterjan <pterjan>
- Define legacy_target_cpu_name on arm

* Sun Feb 16 2020 tv <tv> 2.04.0-3.mga8
+ Revision: 1536651
- don't set arm as EFI only
- set platform as uboot for arm

* Sun Feb 16 2020 tv <tv> 2.04.0-1.mga8
+ Revision: 1535861
- fix build on ia32
- 2.04
- add emu subpkg
- sync patches with FC
- switch to FC way of building
- boot tested in VMs (both PC & UEFI)
- do not abort build for missing builds ids
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Sep 16 2019 tv <tv> 2.02.0-16.mga8
+ Revision: 1441874
- rebuild for rpm-4.15

* Sat May 11 2019 martinw <martinw> 2.02.0-15.mga7
+ Revision: 1397287
- readjust position of informational message bar in maggy theme
  o avoids overlap with Mageia Logo in some languages

* Wed May 08 2019 barjac <barjac> 2.02.0-14.mga7
+ Revision: 1396737
- update fallback b/g image
- brighten menu items colour some more

* Wed May 08 2019 barjac <barjac> 2.02.0-13.mga7
+ Revision: 1396663
- change text colour in theme for Mga7 background

* Sun Jan 20 2019 martinw <martinw> 2.02.0-12.mga7
+ Revision: 1358410
- add extra glyphs to MageiaLogo fonts used in maggy theme (mga#19592)
  o provides all Latin-1 Supplement and Latin Extended-A glyphs
- adjust position of informational message bar in maggy theme
  o avoids overlap with Mageia Logo in some languages

* Thu Dec 20 2018 tv <tv> 2.02.0-11.mga7
+ Revision: 1343475
- fix installing grub2 on a xfs partition (mga#24030)

* Thu Oct 11 2018 pterjan <pterjan> 2.02.0-10.mga7
+ Revision: 1319616
- Add upstream patch which should fix "grub2-install: error: relocation 0x4 is not implemented yet." error on x86_64

* Thu Oct 11 2018 pterjan <pterjan> 2.02.0-9.mga7
+ Revision: 1319413
- Add SuSE patch fixing build with gcc8 on x86_64
- Small fixes to allow the package to build on aarch64
+ umeabot <umeabot>
- Mageia 7 Mass Rebuild

* Fri Jul 13 2018 barjac <barjac> 2.02.0-7.mga7
+ Revision: 1243325
- patch to fix Mga#23268
- (mageia 6: cant boot installation medium (neither usb nor dvd) on direkt-tek DTLAPY116-2)

* Thu Apr 19 2018 barjac <barjac> 2.02.0-6.mga7
+ Revision: 1220250
- Update to grub2-2.02-unity-mkrescue-use-grub2-dir.patch

* Wed Apr 18 2018 barjac <barjac> 2.02.0-5.mga7
+ Revision: 1219973
- Patched to fix Mga#22918
- (grub2-mkrescue still searches /boot/grub for config)
- thanks to Jeremiah Summers for the Unity patch

* Mon Mar 12 2018 martinw <martinw> 2.02.0-4.mga7
+ Revision: 1208657
- Enable translation of labels in the theme configuration file.

* Wed Dec 13 2017 barjac <barjac> 2.02.0-3.mga7
+ Revision: 1182520
- Copy grub.mo rather than link
- Fixes Mga#22182 (grub.mo dangling link)

* Mon Dec 11 2017 barjac <barjac> 2.02.0-2.mga7
+ Revision: 1182161
- requires console-setup (Mga#22153
- (grub2-kbdcomp requires the ckbcomp command which isnt available in Mageia)

* Mon Oct 30 2017 barjac <barjac> 2.02.0-1.mga7
+ Revision: 1175008
- new release 2.02
- Improve version/release handling to simplify full releases and snapshots
- add script to sources make_snapshot_patch to get mid-release snapshots from git
- drop one Fedora patch that fails to apply 10005-Make-a-gdb-dprintf-that-tells-us-load-addresses.patch

* Sun Oct 15 2017 joequant <joequant> 2.02-0.git10463.11.mga7
+ Revision: 1172000
- minimal changes to compile grub2 in cauldron environment
+ tv <tv>
- fix debuginfo, thus fixing build
+ barjac <barjac>
- remove/fix conflicts between grub2 and grub2-efi (mga#21811)
- correct ownership of %%{_libdir}/grub to -common package
- edit to description and cosmetic edit to spec

* Fri Sep 01 2017 tv <tv> 2.02-0.git10463.9.mga7
+ Revision: 1150488
- rebuild for new rpm

* Fri Jun 16 2017 barjac <barjac> 2.02-0.git10463.8.mga6
+ Revision: 1107808
- Change menu title to Mageia Boot Menu

* Mon May 15 2017 barjac <barjac> 2.02-0.git10463.7.mga6
+ Revision: 1101819
- fix Mga#19944 - (grub2 password set in drakboot does not protect booting of linux operating systems)
- Patch to remove --unrestricted when password set

* Tue Mar 21 2017 barjac <barjac> 2.02-0.git10463.6.mga6
+ Revision: 1093925
- set foreground/background colours for non-graphical text mode

* Wed Jan 18 2017 barjac <barjac> 2.02-0.git10463.5.mga6
+ Revision: 1082254
- fix urpmi upgrade from Mga5 to Mga6 Mga#20133
- (urpmi upgrade 5 > 6 loses grub2 background)

* Tue Oct 18 2016 barjac <barjac> 2.02-0.git10463.4.mga6
+ Revision: 1062049
- Add extra glyphs to mageia font Mga#19592
- dont limit range when converting to .pf2 in mkfonts script

* Tue Sep 20 2016 ghibo <ghibo> 2.02-0.git10463.3.mga6
+ Revision: 1054709
- fix permssion of themes png and pf2 files

* Tue Sep 20 2016 barjac <barjac> 2.02-0.git10463.2.mga6
+ Revision: 1054638
- check for default.png not default.jpg

* Tue Sep 20 2016 barjac <barjac> 2.02-0.git10463.1.mga6
+ Revision: 1054558
- really add patch into grub.patches
- s/10462/10463/ typo
- remove obsolete --enable-grub-emu-usb parameter
- fix duplicate file
- use %%make_build and %%make_install macros
- new git snapshot patch
- copy theme b/g directly from default.png now we have it
- tidy spec - remove commented patches

* Wed Sep 07 2016 barjac <barjac> 2.02-0.git10457.17.mga6
+ Revision: 1050417
- fix b/g symlink for systems with separate /boot

* Sun Sep 04 2016 barjac <barjac> 2.02-0.git10457.16.mga6
+ Revision: 1049988
- dont try to copy theme b/g in installer

* Sun Sep 04 2016 barjac <barjac> 2.02-0.git10457.15.mga6
+ Revision: 1049967
- move background image to /themes and symlink from maggy
- to fix path to image file irrespective of whether default or dejavu theme is used
- add conflict for re-named dejavu theme package which will no longer be versioned in the name

* Fri Sep 02 2016 barjac <barjac> 2.02-0.git10457.14.mga6
+ Revision: 1049734
- use correct aspect ratio background if available
- add conflicts for old and new  dejavu themes
- if theme is installed outside installer update menu

* Fri Aug 12 2016 barjac <barjac> 2.02-0.git10457.13.mga6
+ Revision: 1046028
- switch to background with logo at higher resolution

* Mon Aug 08 2016 barjac <barjac> 2.02-0.git10457.12.mga6
+ Revision: 1045031
- first test of mga6 theme
- drop -%%{release} from require of main pkgs in theme to allow easy testing of new themes

* Tue Jul 19 2016 barjac <barjac> 2.02-0.git10457.11.mga6
+ Revision: 1042593
- Patch to ignore test of disk/by-uuid when in installer
- workaround for Mga#18780 ( grub.cfg entries use root=/dev/sdXY instead of root=UUID...)

* Mon Jul 11 2016 barjac <barjac> 2.02-0.git10457.10.mga6
+ Revision: 1041058
- dont write grub2 diskfilter writes not supported error to screen
- mentioned in Mga#18781#1 (dont write sparse file error to screen)

* Sun Jul 10 2016 barjac <barjac> 2.02-0.git10457.9.mga6
+ Revision: 1040611
- fix for Mga#18781
- grub2 flashes error: sparse file not allowed message when booting from btrfs
- patched to ignore the error

* Mon Jun 27 2016 barjac <barjac> 2.02-0.git10457.8.mga6
+ Revision: 1037745
- Dont run old install-sh when upgrading under drakx Mga#15583
- Move rpmnew/save removal outside conditional so it always happens

* Tue Jun 07 2016 barjac <barjac> 2.02-0.git10457.7.mga6
+ Revision: 1020551
- Add SuSE patch to fix Mga#15846
-  (Grub2 doesnt install the bootloader on btrfs if we have a dualboot with windows starting at sector 63)

* Mon Jun 06 2016 barjac <barjac> 2.02-0.git10457.6.mga6
+ Revision: 1020311
- On update be sure all grub2 pkgs are installed before running install.sh
+ tv <tv>
- drop 90_persistent script like FC did as:
  o it is undocumented.
  o it haven't been upstreamed.
  o upstream has 40_custom and 41_custom for the same purpose.
  o it violates layering and code structure by guessing which (optional!) output
    file has been specified for grub2-mkconfig ... and makes the wrong guess for
    grub2-efi.
- there's no reason to recommends memtest86+ (bloating)

* Sat May 28 2016 barjac <barjac> 2.02-0.git10457.5.mga6
+ Revision: 1019042
- remove disk cache patch pushed to release in error

* Fri May 27 2016 barjac <barjac> 2.02-0.git10457.4.mga6
+ Revision: 1018949
- move unicode.pf2 to /usr/share/grub Mga#18552

* Thu May 26 2016 barjac <barjac> 2.02-0.git10457.3.mga6
+ Revision: 1018836
- remove non-graphical menu colours from custom.cfg
+ tv <tv>
- add details

* Thu May 26 2016 tv <tv> 2.02-0.git10457.2.mga6
+ Revision: 1018772
- increase disk cache (mga#16010, mga#18538)

* Mon May 09 2016 barjac <barjac> 2.02-0.git10457.1.mga6
+ Revision: 1011161
- create snapshot patch with revision #
- use git apply rather than git am or patches fail to apply
- use correct git revision in package name

* Sat May 07 2016 tmb <tmb> 2.02-0.git10270.8.mga6
+ Revision: 1010339
- submit to /release

* Fri May 06 2016 barjac <barjac> 2.02-0.git10270.7.mga6
+ Revision: 1009668
- remove TPM/secure boot patches from fd

* Thu Apr 28 2016 barjac <barjac> 2.02-0.git10270.6.mga6
+ Revision: 1007014
- use grub.patches to unclutter spec
- use one line per buildrequire as Mageia policy
- fix spaces/tabs

* Tue Apr 26 2016 tv <tv> 2.02-0.git10270.5.mga6
+ Revision: 1006392
- one more fix from FC

* Tue Apr 26 2016 tv <tv> 2.02-0.git10270.4.mga6
+ Revision: 1006391
- BS do not seem to like %%include
- 2.02 beta3
- sync patches with FC

* Tue Mar 15 2016 tv <tv> 2.02-0.git10270.3.mga6
+ Revision: 990802
- kill doble BR
- reorder BRs like FC (easier syncing)
- add git BR
- adjust file list
- sync patches with FC
- apply them with git like FC does
  (thus helping syncing them...)
- drop one mga patch as it's already in FC stack

* Wed Feb 10 2016 tv <tv> 2.02-0.git10270.2.mga6
+ Revision: 953531
- drop recommends on theme (now handled by drakboot) (mga#9431)

* Mon Jan 25 2016 barjac <barjac> 2.02-0.git10270.1.mga6
+ Revision: 927090
- new snapshot 10270
- dont build empty grub2 package in arm
- remove obsolete patches
- re-diff one patch
- fix tabs/spaces

* Fri Jan 22 2016 neoclust <neoclust> 2.02-0.git10101.8.mga6
+ Revision: 926545
- Add Arm support

* Tue Jan 05 2016 barjac <barjac> 2.02-0.git10101.7.mga6
+ Revision: 919799
- upstream patch to fix halt on some hardware Mga#17437

* Tue Dec 15 2015 barjac <barjac> 2.02-0.git10101.6.mga6
+ Revision: 910713
- fix for CVE-2015-8370 Mga#17334 buffer overflow when checking password
- also added Fedora patch to use only GRUB2_PASSWORD

* Sat Dec 05 2015 barjac <barjac> 2.02-0.git10101.5.mga6
+ Revision: 908418
- push to core and bump release to give testers of Mga#17263 another update
- (grub2 updates create several .rpmnew which removes boot menu)

* Tue Dec 01 2015 barjac <barjac> 2.02-0.git10101.4.mga6
+ Revision: 907432
- Stop rpmnew files being offered on update Mga#17263
- by dis-owning grub.cfg which is always now written by other packages
- delete /etc/default/grub.rpmnew on updates to stop it being offered
- remove grub2-efi %%triggerpostun as it is covered by a new one used to recreate grub.cfg once only
- remove some old log files with the same trigger and stop creating them

* Mon Nov 23 2015 barjac <barjac> 2.02-0.git10101.3.mga6
+ Revision: 905032
- add warning to grub2-efi description and
- remove old misleading info from description

* Mon Nov 16 2015 barjac <barjac> 2.02-0.git10101.2.mga6
+ Revision: 903489
- move 93_memtest to memtest package #Mga15914
- recommend memtest
- move recommends os-prober and theme to common
- conflict older memtest86+ packages

* Tue Sep 08 2015 barjac <barjac> 2.02-0.git10101.1.mga6
+ Revision: 873987
- new snapshot
- synced patches from Fedora
- re-diffed failsafe  patch
- new BR pkgconfig(rpm)
- fix files list

* Fri Sep 04 2015 barjac <barjac> 2.02-0.git9752.22.mga6
+ Revision: 872680
+ rebuild (emptylog)

* Thu Sep 03 2015 barjac <barjac> 2.02-0.git9752.21.mga6
+ Revision: 872503
- Patch to fix Mga#16672
- Dont munge raw spaces when passing kernel parameters

* Fri Aug 21 2015 tmb <tmb> 2.02-0.git9752.20.mga6
+ Revision: 867458
- rebuild for new gcc

* Sat Jul 11 2015 barjac <barjac> 2.02-0.git9752.19.mga6
+ Revision: 853282
- split out common files into grub2-common Mga#15913
- initially set GRUB_DISABLE_RECOVERY=false

* Tue Apr 14 2015 barjac <barjac> 2.02-0.git9752.18.mga5
+ Revision: 820184
- update README.mageia for no filetriggers
- remove all filetriggers
- stop %%posts failing when grub2 is not bootloader
- update README files

* Mon Apr 13 2015 barjac <barjac> 2.02-0.git9752.17.mga5
+ Revision: 820103
- Add failsafe rather than single in rescue mode Mga#15675
- remove modules part of filetrigger filter (kernel updates) now handled by drakx

* Fri Apr 10 2015 tmb <tmb> 2.02-0.git9752.15.mga5
+ Revision: 820032
- only Recommend xorriso to avoid bloated installs

* Thu Apr 09 2015 tv <tv> 2.02-0.git9752.14.mga5
+ Revision: 819995
- simplify %%post, just rely on /boot/grub2/install.sh (mga#11827)

* Tue Mar 24 2015 tv <tv> 2.02-0.git9752.13.mga5
+ Revision: 819208
- grub2-mkimage needs XZ support
+ barjac <barjac>
- Add Requires: xorriso for grub2-mkrescue -  mga#15514

* Mon Jan 05 2015 tmb <tmb> 2.02-0.git9752.12.mga5
+ Revision: 808518
- grub2-efi
  * only run post during install, not on upgrade
  * fix installing from live mode

* Mon Jan 05 2015 barjac <barjac> 2.02-0.git9752.11.mga5
+ Revision: 808473
- BOOT_PARTITION was used before being defined in %%post

* Tue Dec 16 2014 barjac <barjac> 2.02-0.git9752.10.mga5
+ Revision: 803582
- update theme for Mageia 5

* Wed Dec 10 2014 barjac <barjac> 2.02-0.git9752.9.mga5
+ Revision: 802633
- added GRUB_CRYPTODISK_ENABLE=y to default config mga#14741
- patch to fix regression when GRUB_CRYPTODISK_ENABLE=y with no encrypted partitions

* Wed Oct 15 2014 umeabot <umeabot> 2.02-0.git9752.8.mga5
+ Revision: 739167
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2.02-0.git9752.7.mga5
+ Revision: 679954
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Wed Aug 20 2014 luigiwalser <luigiwalser> 2.02-0.git9752.6.mga5
+ Revision: 666017
- rediff patch from harbour to fix CVE-2014-4607 in bundled minilzo

* Sat Jul 05 2014 pterjan <pterjan> 2.02-0.git9752.5.mga5
+ Revision: 643675
- Replace libusb*-devel BuildRequires by better ones

* Wed Jun 11 2014 barjac <barjac> 2.02-0.git9752.4.mga5
+ Revision: 635563
- drop linuxefi Fedora patches
- drop reverted patch pair
- drop Don-t-write-messages-to-the-screen.patch temporarily
- add versioned rpm trigger to grub2-efi to update grub.cfg when updating from below this version

* Tue Jun 03 2014 tmb <tmb> 2.02-0.git9752.2.mga5
+ Revision: 632621
- re-add support for linuxefi target

* Sun Jun 01 2014 barjac <barjac> 2.02-0.git9752.1.mga5
+ Revision: 629976
- new git snapshot
- fix mga 12423 for most cases
- fix typos in readme
- remove upstreamed patches

* Tue Mar 18 2014 pterjan <pterjan> 2.00-59.mga5
+ Revision: 605125
- Fix build

* Sun Jan 05 2014 ennael <ennael> 2.00-58.mga4
+ Revision: 564767
- rename background file
- rename Mageia background image
- Mageia 4 design

* Wed Nov 13 2013 barjac <barjac> 2.00-57.mga4
+ Revision: 550910
- remove Fedora patches that affect text only menu layout

* Tue Nov 12 2013 barjac <barjac> 2.00-56.mga4
+ Revision: 550657
- add Fedora patches not applied upstream
- drop virtual provide on theme

* Sun Nov 10 2013 tmb <tmb> 2.00-55.mga4
+ Revision: 550414
- grub2-mageia-theme: dont conflict own virtual provide

* Sat Nov 09 2013 barjac <barjac> 2.00-54.mga4
+ Revision: 550058
- git snapshot
- add GRUB_DISABLE_SUBMENU to etc/default/grub as example (no change to default)

* Tue Nov 05 2013 tmb <tmb> 2.00-53.mga4
+ Revision: 549704
- fix install from live mode

* Tue Nov 05 2013 barjac <barjac> 2.00-52.mga4
+ Revision: 549519
- re-install grub2 on updates if drakboot.conf exists

* Sat Oct 26 2013 tmb <tmb> 2.00-51.mga4
+ Revision: 547151
- have grub2-efi require efibootmgr for more automated install

* Mon Oct 21 2013 umeabot <umeabot> 2.00-50.mga4
+ Revision: 539292
- Mageia 4 Mass Rebuild

* Sat Oct 05 2013 barjac <barjac> 2.00-49.mga4
+ Revision: 491788
- fix mga#11168 (remove linux)

* Thu Jul 04 2013 barjac <barjac> 2.00-48.mga4
+ Revision: 450000
- remove virtual provides versioning
- make theme package noarch
- add provides/conflicts grub2theme to allow other themes
- just remove old theme from config
- own theme sub dir and remove it from postun

* Mon Jul 01 2013 barjac <barjac> 2.00-47.mga4
+ Revision: 449511
- improve appearance of non-themed text menu with Mageia-ish colours

* Thu May 23 2013 barjac <barjac> 2.00-46.mga4
+ Revision: 425400
- revert previous commit

* Wed May 08 2013 barjac <barjac> 2.00-45.mga3
+ Revision: 412632
- remove filetrigger for kernel updates as this should now be handled by bootloader
- remove memtest support until after mga3 release

* Mon May 06 2013 barjac <barjac> 2.00-44.mga3
+ Revision: 412411
- put memtest always at bottom of menu

* Mon May 06 2013 barjac <barjac> 2.00-43.mga3
+ Revision: 412404
- add support for memtest86+ mga#9991
- revert %%post removal in prev commit

* Sat May 04 2013 barjac <barjac> 2.00-42.mga3
+ Revision: 412225
- remove %%post
- remove require on mageia-theme

* Sun Mar 24 2013 barjac <barjac> 2.00-41.mga3
+ Revision: 404821
- include tarball of master bdf fonts
- update mkfonts script to make needed pf2 fonts from bdf tarball
- updated theme fonts to fix some glyphs
- thanks to diogenese for work on unofficial MageiaLogo font
- update fonts

* Fri Mar 22 2013 barjac <barjac> 2.00-40.mga3
+ Revision: 404429
- fix update-grub env so os-prober can find blkid

* Mon Mar 18 2013 barjac <barjac> 2.00-39.mga3
+ Revision: 403927
- switch to mageia 3 theme background

* Mon Mar 11 2013 barjac <barjac> 2.00-38.mga3
+ Revision: 402075
- change theme font to MageiaLogo
- corrections and improvements to README.Mageia

* Thu Mar 07 2013 barjac <barjac> 2.00-37.mga3
+ Revision: 401594
- move theme background image into package as it will be for mga3 release

* Tue Mar 05 2013 tv <tv> 2.00-36.mga3
+ Revision: 401431
- only update grub2.cfg if already existing
- no need for bash

* Mon Mar 04 2013 barjac <barjac> 2.00-35.mga3
+ Revision: 401408
- correct path

* Wed Feb 27 2013 barjac <barjac> 2.00-34.mga3
+ Revision: 400520
- set default timeout to 10 seconds

* Mon Feb 25 2013 barjac <barjac> 2.00-33.mga3
+ Revision: 400332
- add update-grub & update-grub2 (symlink)
- update README.Mageia for above
- add note in /etc/default/grub
- no need to patch aclocal.m4
- patch13 to fix autoreconf AM_PROG_MKDIR_P warnings

* Sat Feb 23 2013 barjac <barjac> 2.00-32.mga3
+ Revision: 400190
- revert to using unicode font for terminal
- remove make tarball script
- remove 7x13.pf2 font file
- modify mkfonts script to not make 7x13.pf2
- re-enumerate sources

* Sat Feb 23 2013 barjac <barjac> 2.00-31.mga3
+ Revision: 400102
- improved workaround for RHL Bug 817187, removing it from %%post

* Fri Feb 22 2013 barjac <barjac> 2.00-30.mga3
+ Revision: 400001
- suppress error message on minimal install with --no-suggests #9148

* Wed Feb 20 2013 tv <tv> 2.00-29.mga3
+ Revision: 399495
- do not package huge ChangeLog

* Mon Feb 18 2013 barjac <barjac> 2.00-28.mga3
+ Revision: 399253
- clean up files
- add -n (no-clobber) to prevoius cp workaround for when this is fixed upstream

* Sat Feb 16 2013 barjac <barjac> 2.00-27.mga3
+ Revision: 398620
- Workaround for RHL Bug 817187

* Sun Feb 10 2013 barjac <barjac> 2.00-26.mga3
+ Revision: 397694
- run autogen.sh in both build trees

* Sun Feb 10 2013 pterjan <pterjan> 2.00-25.mga3
+ Revision: 397685
- Fix parallel build

* Sun Feb 10 2013 barjac <barjac> 2.00-24.mga3
+ Revision: 397678
- try non-parallel build
- forgot to apply all patches to both builds

* Sat Feb 09 2013 barjac <barjac> 2.00-23.mga3
+ Revision: 397663
- cherry picked patches from Fedora

* Sat Feb 09 2013 barjac <barjac> 2.00-22.mga3
+ Revision: 397534
- improved handling of theme addition/removal from /etc/default/grub
- fixes bug where someone has removed linefeed from file end or has commented the THEME= line

* Fri Feb 08 2013 barjac <barjac> 2.00-21.mga3
+ Revision: 397190
- update theme with new font
- add custom.cfg
- new mkfonts script
- re-enumerated sources
- cleaned GNU/Linux from cluttering menus
- matched font colours to Mageia logo
- make grub2-efi also own /boot/grub2 ;)

* Fri Feb 08 2013 tmb <tmb> 2.00-20.mga3
+ Revision: 397106
- own /boot/grub2 dir too

* Thu Feb 07 2013 barjac <barjac> 2.00-19.mga3
+ Revision: 395043
- added warning note inside /etc/default/grub

* Wed Feb 06 2013 barjac <barjac> 2.00-18.mga3
+ Revision: 394991
- split out theme into separate package
- theme now Suggested
- os-prober and theme addition/removal handled by filetriggers
- updated README.Mageia to reflect above changes
- added option for disabling os-prober to /etc/default/grub

* Mon Feb 04 2013 barjac <barjac> 2.00-17.mga3
+ Revision: 394533
- os-prober should be Suggests

* Mon Jan 28 2013 barjac <barjac> 2.00-16.mga3
+ Revision: 392864
- edited help text in boot screen

* Fri Jan 25 2013 barjac <barjac> 2.00-15.mga3
+ Revision: 392262
- force copy of theme b/g for updates

* Thu Jan 24 2013 barjac <barjac> 2.00-14.mga3
+ Revision: 391754
- copy theme b/g to /boot when /boot is on separate partition in case / is encrypted

* Sun Jan 20 2013 barjac <barjac> 2.00-13.mga3
+ Revision: 390289
- update group

* Wed Jan 16 2013 barjac <barjac> 2.00-12.mga3
+ Revision: 388457
- add provides bootloader to both packages
- add suggests mageia-theme to -efi package

* Sat Jan 12 2013 umeabot <umeabot> 2.00-11.mga3
+ Revision: 352682
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Dec 24 2012 barjac <barjac> 2.00-10.mga3
+ Revision: 334731
- updated description and README.Mageia

* Mon Dec 17 2012 tv <tv> 2.00-9.mga3
+ Revision: 331864
- fix build with official version
- use official tarball (which includes translations)

* Sat Dec 15 2012 tv <tv> 2.0-8.mga3
+ Revision: 331059
- suggests instead of requiring mageia-theme

* Sat Dec 15 2012 tv <tv> 2.0-7.mga3
+ Revision: 331055
- requires mageia-theme (else image symlink is broken for graphical grub)

* Thu Nov 15 2012 barjac <barjac> 2.0-6.mga3
+ Revision: 318311
- corrected url
- minor edits in desription and README.Mageia

* Wed Oct 10 2012 barjac <barjac> 2.0-5.mga3
+ Revision: 304517
- Fix i586 build with configure2_5x

* Sun Sep 30 2012 barjac <barjac> 2.0-4.mga3
+ Revision: 300624
- Changed group in line with new policy

* Mon Sep 17 2012 barjac <barjac> 2.0-3.mga3
+ Revision: 295597
- patch to fix build against glibc-2.16
- improved description

* Fri Jun 29 2012 barjac <barjac> 2.0-2.mga3
+ Revision: 265181
- New version final release of v2.0
- Removed revision from filename as this is a release
- Added Suggests on efibootmgr
- Moved files efi to end of spec
- Removed README.efi from grub2 rpm
- Added explanation about -efi rpm to README.Mageia
- Changed var name in grub.default as changed upstream

* Sun Jun 03 2012 barjac <barjac> 2.0-1.4412.mga3
+ Revision: 253509
- Updated README.efi
- Updated revision
- Fixed updates deleting files in preun
- Removed redundant code in install section
- Corrected minor scripting error in mk_tar_from_grub_trunk

* Tue May 29 2012 barjac <barjac> 2.0-1.4379.mga3
+ Revision: 248863
- Removed dot from one summary
- imported package grub2

